/**********************************************************************************************
 * 
 * ADOBE CONFIDENTIAL
 * 
 * Copyright 2013 Adobe Systems Incorporated. All Rights Reserved.
 * 
 * NOTICE: All information contained herein is, and remains the property of Adobe Systems
 * Incorporated and its suppliers, if any. The intellectual and technical concepts contained
 * herein are proprietary to Adobe Systems Incorporated and its suppliers and are protected
 * by trade secret or copyright law. Dissemination of this information or reproduction of
 * this material is strictly forbidden unless prior written permission is obtained from
 * Adobe Systems Incorporated.
 * 
 **********************************************************************************************/

(function() {

	// Utility: walk through the existing DOM and call the callback function for all of 
	// the specified node type. 
	function walkDOMNodes(object, callback, nodeType ) {

		// exit when object is null
		if (!object) {
			return;
		}

		if (object.nodeType && object.nodeType === nodeType) {
			callback(object);
		}

		if (object.contentDocument) {
                walkDOMNodes(object.contentDocument, callback, nodeType);
		}

		if (object.children) {
			for (var kid = object.firstChild; kid; kid = kid.nextSibling) {
                walkDOMNodes(kid, callback, nodeType);
			}
		}
	};

	// open the target in a new window, according to our business rules.
	function newWindowEventListener(event) {
		var target = event.target;
		
		while (target != null) {

			// If this node is an anchor
			if (target.nodeName.toLowerCase() === "a" && target.getAttribute("href")) {
				// Check if each part of the url except the hash matches
				var samePage = target.protocol == window.location.protocol
					&& target.host == window.location.host
					&& target.pathname == window.location.pathname
					&& target.search == window.location.search;
					
				if (!samePage) {
					event.preventDefault();
					_adobedps_native_overlay.openInNewWindow(target.href);
					return false;
				}
			}
			
			// If this node isn't an anchor check its parent
			target = target.parentNode;
		}
	}

	// add the newWindowEventListener to the specified target.
	function addNewWindowEventListener(eventTarget) {
		//
		// Note the addition of the last parameter (custom to Adobe DPS): true to apply event listener
		// directly to HTML (and not apply Adobe event suppression).
		eventTarget.addEventListener("click", newWindowEventListener, false, true);
	}


	// Listen for any click events that bubble up to the window
	//
	// Note the addition of the last parameter (custom to Adobe DPS): true to apply event listener
	// directly to HTML (and not apply Adobe event suppression).
	window.addEventListener("click", newWindowEventListener, false, true);

	// iframe events are not allowed to bubble, so we need to inject into them separately
	walkDOMNodes(document.body, addNewWindowEventListener, Node.DOCUMENT_NODE);	


	// Override window.open functionality
	window.open = function(strUrl, strWindowName, strWindowFeatures)
	{
		// Trick to convert relative url to absolute
		var anchor = document.createElement("a");
		anchor.href = strUrl;
		
		_adobedps_native_overlay.openInNewWindow(anchor.href);
	};

})();
